@@ -81,7 +81,7 @@ html_image_get_actual_width (HTMLImage *image, HTMLPainter *painter)
 
 	if (image->percent_width) {
 		/* The cast to `gdouble' is to avoid overflow (eg. when
-                   printing).  */
+		   printing).  */
 		width = ((gdouble) HTML_OBJECT (image)->max_width
 			 * image->specified_width) / 100;
 	} else if (image->specified_width > 0) {
@@ -114,7 +114,7 @@ html_image_get_actual_height (HTMLImage *image, HTMLPainter *painter)
 
 	if (image->percent_height) {
 		/* The cast to `gdouble' is to avoid overflow (eg. when
-                   printing).  */
+		   printing).  */
 		height = ((gdouble) html_engine_get_view_height (image->image_ptr->factory->engine)
 			  * image->specified_height) / 100;
 	} else if (image->specified_height > 0) {
@@ -1162,13 +1162,13 @@ html_image_pointer_queue_animation (HTMLImagePointer *ip)
 		delay = gdk_pixbuf_animation_iter_get_delay_time (ip->iter);
 
 		ip->animation_timeout = g_timeout_add (delay,
-						       (GtkFunction) html_image_pointer_update,
+						       (GSourceFunc) html_image_pointer_update,
 						       (gpointer) ip);
 	}
 
 }
 
-static gint
+static gboolean
 html_image_pointer_update (HTMLImagePointer *ip)
 {
 	HTMLEngine *engine;
@@ -1319,7 +1319,7 @@ html_image_pointer_new (const gchar *filename, HTMLImageFactory *factory)
 	retval->factory = factory;
 	retval->stall = FALSE;
 	retval->stall_timeout = g_timeout_add (STALL_INTERVAL,
-					       (GtkFunction)html_image_pointer_timeout,
+					       (GSourceFunc) html_image_pointer_timeout,
 					       retval);
 	retval->animation_timeout = 0;
 	return retval;
@@ -1344,7 +1344,7 @@ html_image_pointer_timeout (HTMLImagePointer *ip)
 	 */
 	if (ip->animation == NULL) {
 		while (list) {
-			image = (HTMLImage *)list->data;
+			image = (HTMLImage *) list->data;
 
 			if (image)
 				html_engine_queue_draw (ip->factory->engine,
